==> CRTL-0.16.3-py3-none-any.whl: crtl/components/dual_encoder/annotation.py <==
from candidate import Candidate

from typing import List

from spacy.tokens import Span


class Annotation:
    """
    Annotation

    The Annotation class represents a name mention in the text that could potentialy be linked to an entity, with its potential candidates.

    ------------
    PARAMS:

    span: Span
        The SpaCy span that contains the entity mention
    candidates: Array[Candidate]
        The list of potential candidate entity links for the annotation

    """

    def __init__(self, span: Span, candidates: List[Candidate] = []):
        self.span = span
        self.candidates = candidates

    def get_best_candidate(self):
        best_candidate = None
        for candidate in self.candidates:
            if best_candidate == None or candidate.score > best_candidate.score:
                best_candidate = candidate
        return best_candidate

    def is_valid(self, min_idx: int, max_idx: int) -> bool:
        """
        is_valid

        Checks whether the annotation span is valid, ie. whether it is in bounds of the text and start_idx < end_idx

        min_idx: int
            The minimum token index of the context window
        max_idx: int
            The maximum token index of the context window
        """
        if self.span.start < min_idx or self.span.end >= max_idx:
            return False
        return self.span.start < self.span.end

    def get_annotated_string(self):
        """
        get_annotated_string

        Gets a readable string representation of the annotation, with annotations displayed
        """
        FMT = "\033[94m" + "\033[1m"
        ENDFMT = "\033[0m"
        best_candidate = self.get_best_candidate()
        if best_candidate == None:
            return self.span.text + " "
        return (
            FMT + "[{}]({})".format(self.span.text, best_candidate.entity.name) + ENDFMT
        )

    def __str__(self):
        return self.span.text.replace("\n", " ")
        # "{} {}-{}".format(self.span.text, self.span.start, self.span.end)

==> CRTL-0.26.0-py3-none-any.whl: crtl/components/dual_encoder/annotation.py <==
from candidate import Candidate

from typing import List

from spacy.tokens import Span


class Annotation:
    """
    Annotation

    The Annotation class represents a name mention in the text that could potentialy be linked to an entity, with its potential candidates.

    ------------
    PARAMS:

    span: Span
        The SpaCy span that contains the entity mention
    candidates: Array[Candidate]
        The list of potential candidate entity links for the annotation

    """

    def __init__(self, span: Span, candidates: List[Candidate] = []):
        self.span = span
        self.candidates = candidates

    def get_best_candidate(self) -> Candidate:
        best_candidate: Candidate = None
        for candidate in self.candidates:
            if best_candidate == None or candidate.score > best_candidate.score:
                best_candidate = candidate
        return best_candidate

    def is_valid(self, min_idx: int, max_idx: int) -> bool:
        """
        is_valid

        Checks whether the annotation span is valid, ie. whether it is in bounds of the text and start_idx < end_idx

        min_idx: int
            The minimum token index of the context window
        max_idx: int
            The maximum token index of the context window
        """
        if self.span.start < min_idx or self.span.end >= max_idx:
            return False
        return self.span.start < self.span.end

    def get_annotated_string(self):
        """
        get_annotated_string

        Gets a readable string representation of the annotation, with annotations displayed
        """
        FMT = "\033[94m" + "\033[1m"
        ENDFMT = "\033[0m"
        best_candidate = self.get_best_candidate()
        if best_candidate == None:
            return self.span.text + " "
        return FMT + f"[{self.span.text}]({best_candidate.entity.name})" + ENDFMT

    def __str__(self):
        return self.span.text.replace("\n", " ")
        # "{} {}-{}".format(self.span.text, self.span.start, self.span.end)
